Retrieve series info for given table id and coordinates
Source:R/cansim_metadata.R
add_cansim_vectors_to_template.RdRetrieves vector information for given table and coordinates. This can be used to query data by vectors, it only returns vector information on coordinates which are present in the data table, so it gives an effective way to filter coordinates. Vector information is not available for census data tables.
Value
a tibble containing the table template with added vector information
Returns NULL if the data could not be retrieved because StatCan is unavailable.
Examples
if (FALSE) { # \dontrun{
template <- get_cansim_table_template("34-10-0013")
template |>
filter(Geography=="Canada") |>
add_cansim_vectors_to_template()
} # }