get_cansim_changed_tables: Retrieve a list of modified tables since a given date

get_cansim_changed_tablesR Documentation

Retrieve a list of modified tables since a given date

Description

Retrieve a list of tables that have been modified or updated since the specified date.

Usage

get_cansim_changed_tables(start_date, end_date = NULL)

Arguments

start_date

Starting date in YYYY-MM-DD format to look for changes that changed on or after that date

end_date

Optional end date in YYYY-MM-DD format to look for changes that changed on or before that date, default is same as start date

Value

A tibble with Statistics Canada data table product ids and their release times

Returns NULL if the data could not be retrieved because StatCan is unavailable.

Examples


get_cansim_changed_tables("2018-08-01")


cansim documentation built on Aug. 20, 2026, 1:07 a.m.