get_cansim_table_last_release_date: Get the latest release data for a StatCan table, if available

get_cansim_table_last_release_dateR Documentation

Get the latest release data for a StatCan table, if available

Description

This can be used to check when a table has last been updated.

Usage

get_cansim_table_last_release_date(cansimTableNumber)

Arguments

cansimTableNumber

the NDM table number

Value

A datetime object if a release data is available, NULL otherwise.

Returns NULL if the data could not be retrieved because StatCan is unavailable.

Examples


get_cansim_table_last_release_date("34-10-0013")


cansim documentation built on Aug. 20, 2026, 1:07 a.m.