View source: R/cansim_vectors.R
| get_cansim_vector_info | R Documentation |
Allows for the retrieval of metadata for Statistics Canada data vectors
get_cansim_vector_info(vectors)
vectors |
a vector of cansim vectors |
A tibble with metadata for selected vectors
Returns NULL if the data could not be retrieved because StatCan is unavailable.
get_cansim_vector_info("v41690973")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.