| search_cansim_cubes | R Documentation |
Searches through Statistics Canada data cubes using a search term.
search_cansim_cubes(search_term, refresh = FALSE)
search_term |
User-supplied search term used to find Statistics Canada data cubes with matching titles, table numbers, subject and survey codes. |
refresh |
Default is |
A tibble with available Statistics Canada data cubes, listing title, Statistics Canada data cube catalogue number, deprecated CANSIM table number, survey and subject.
Returns NULL if the data could not be retrieved because StatCan is unavailable.
## Not run:
search_cansim_cubes("Labour force")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.