Retrieve a list of modified tables since a given date
Source:R/cansim.R
get_cansim_changed_tables.RdRetrieve a list of tables that have been modified or updated since the specified date.
Value
A tibble with Statistics Canada data table product ids and their release times
Returns NULL if the data could not be retrieved because StatCan is unavailable.
Examples
# \donttest{
get_cansim_changed_tables("2018-08-01")
#> # A tibble: 8 × 2
#> productId releaseTime
#> <int> <chr>
#> 1 23100251 2018-08-01T08:35
#> 2 33100036 2018-08-01T08:30
#> 3 10100139 2018-08-01T08:30
#> 4 10100125 2018-08-01T08:30
#> 5 10100107 2018-08-01T08:30
#> 6 33100005 2018-08-01T08:30
#> 7 33100033 2018-08-01T08:30
#> 8 33100084 2018-08-01T08:30
# }