powered by
Retrieve a list of tables that have been modified or updated since the specified date.
get_cansim_changed_tables(start_date, end_date = NULL)
A tibble with Statistics Canada data table product ids and their release times
Returns NULL if the data could not be retrieved because StatCan is unavailable.
NULL
Starting date in YYYY-MM-DD format to look for changes that changed on or after that date
YYYY-MM-DD
Optional end date in YYYY-MM-DD format to look for changes that changed on or before that date, default is same as start date
# \donttest{ get_cansim_changed_tables("2018-08-01") # }
Run the code above in your browser using DataLab