get_cansim_code_set: Get NDM code sets

get_cansim_code_setR Documentation

Get NDM code sets

Description

Useful to get a list of surveys or subjects and used internally

Usage

get_cansim_code_set(
  code_set = c("scalar", "frequency", "symbol", "status", "uom", "survey", "subject",
    "wdsResponseStatus"),
  refresh = FALSE
)

Arguments

code_set

the code set to retrieve.

refresh

Default is FALSE, repeated calls during the same session will hit the cached data. To refresh the code list during a running R session set to TRUE

Value

A tibble with english and french labels for the given code set

Returns NULL if the data could not be retrieved because StatCan is unavailable.

Examples


get_cansim_code_set("survey")


cansim documentation built on Aug. 20, 2026, 1:07 a.m.