powered by
Useful to get a list of surveys or subjects and used internally
get_cansim_code_set( code_set = c("scalar", "frequency", "symbol", "status", "uom", "survey", "subject", "wdsResponseStatus"), refresh = FALSE )
A tibble with english and french labels for the given code set
Returns NULL if the data could not be retrieved because StatCan is unavailable.
NULL
the code set to retrieve.
Default is FALSE, repeated calls during the same session will hit the cached data. To refresh the code list during a running R session set to TRUE
FALSE
TRUE
# \donttest{ get_cansim_code_set("survey") # }
Run the code above in your browser using DataLab