a tibble containing the series information for the given coordinates
Returns NULL if the data could not be retrieved because StatCan is unavailable.
Arguments
cansimTableNumber
A new or old CANSIM/NDM table number, coordinates are specific to a single table
coordinates
A vector of coordinates
timeout
(Optional) Number of seconds StatCan is allowed to go without sending data before the call is abandoned. This does not limit how long the call may take overall, a response that keeps arriving is left alone.