powered by
This can be used to check when a table has last been updated.
get_cansim_table_last_release_date(cansimTableNumber)
A datetime object if a release data is available, NULL otherwise.
Returns NULL if the data could not be retrieved because StatCan is unavailable.
NULL
the NDM table number
# \donttest{ get_cansim_table_last_release_date("34-10-0013") # }
Run the code above in your browser using DataLab