Learn R Programming

cansim (version 0.5.0)

get_cansim_table_overview: Retrieve Statistics Canada data table overview text

Description

Prints table overview information as console output. In order to display table overview information, the selected CANSIM table must be loaded entirely to display overview information. Overview information is printed in console an in English or French, as specified.

Usage

get_cansim_table_overview(
  cansimTableNumber,
  language = "english",
  refresh = FALSE
)

Value

none

Nothing is printed if the data could not be retrieved because StatCan is unavailable.

Arguments

cansimTableNumber

the NDM table number to load

language

"english" (the default) or "french". Short forms such as "en", "eng", "fr" or "fra" are accepted, as are the French names "anglais" and "francais"; case and accents are ignored

refresh

(Optional) When set to TRUE, forces a reload of data table (default is FALSE)

Examples

Run this code
# \donttest{
get_cansim_table_overview("34-10-0013")
# }

Run the code above in your browser using DataLab