| get_cansim_table_template | R Documentation |
A table template consists of the dimensions and members and coordinates of a table that can be used to explore and filter table data before downloading subsets of the table. To add vector Ids to (a possibly filtered) template the 'add_cansim_vectors_to_template' function can be used.
get_cansim_table_template(
cansimTableNumber,
language = "english",
refresh = FALSE
)
cansimTableNumber |
A new or old CANSIM/NDM table number or a vector of table numbers |
language |
|
refresh |
Refresh the data from the Statistics Canada API |
a tibble containing the table template, with a 'cansimTableNumber' column identifying the table. When several table numbers are given, the templates are stacked and columns for dimensions that only appear in some of the tables are filled with 'NA' for the other tables.
Returns NULL if the data could not be retrieved because StatCan is unavailable.
get_cansim_table_template("34-10-0013")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.