a tibble containing the table template, with a `cansimTableNumber` column identifying the table.
When several table numbers are given, the templates are stacked and columns for dimensions that only appear
in some of the tables are filled with `NA` for the other tables.
Returns NULL if the data could not be retrieved because StatCan is unavailable.