Learn R Programming

cansim (version 0.5.0)

get_cansim_vector_info: Retrieve metadata for specified Statistics Canada data vectors

Description

Allows for the retrieval of metadata for Statistics Canada data vectors

Usage

get_cansim_vector_info(vectors)

Value

A tibble with metadata for selected vectors

Returns NULL if the data could not be retrieved because StatCan is unavailable.

Arguments

vectors

a vector of cansim vectors

Examples

Run this code
# \donttest{
get_cansim_vector_info("v41690973")
# }

Run the code above in your browser using DataLab