powered by
Allows for the retrieval of metadata for Statistics Canada data vectors
get_cansim_vector_info(vectors)
A tibble with metadata for selected vectors
Returns NULL if the data could not be retrieved because StatCan is unavailable.
NULL
a vector of cansim vectors
# \donttest{ get_cansim_vector_info("v41690973") # }
Run the code above in your browser using DataLab