Learn R Programming

cansim (version 0.5.0)

list_cansim_sqlite_cached_tables: List cached cansim SQLite database (deprecated)

Description

This method is deprecated and will be removed in a future version, please use `list_cansim_cached_tables()` instead.

Usage

list_cansim_sqlite_cached_tables(
  cache_path = Sys.getenv("CANSIM_CACHE_PATH"),
  refresh = FALSE
)

Value

A tibble with the list of all tables that are currently cached at the given cache path.

Arguments

cache_path

Optional, default value is `Sys.getenv('CANSIM_CACHE_PATH')`.

refresh

Optional, refresh the last updated date of cached cansim tables

Examples

Run this code
if (FALSE) {
list_cansim_cached_tables()
}

Run the code above in your browser using DataLab