| remove_cansim_sqlite_cached_table | R Documentation |
This method is deprecated and will be removed in a future version, please use 'remove_cansim_cached_tables(..., format="sqlite")' instead.
remove_cansim_sqlite_cached_table(
cansimTableNumber,
language = NULL,
cache_path = Sys.getenv("CANSIM_CACHE_PATH")
)
cansimTableNumber |
Number of the table to be removed |
language |
Language for which to remove the cached data, named as in |
cache_path |
Optional, default value is ‘Sys.getenv(’CANSIM_CACHE_PATH')' |
'NULL“
## Not run:
con <- get_cansim_connection("34-10-0013", format="sqlite")
disconnect_cansim_connection(con)
remove_cansim_cached_tables("34-10-0013", format="sqlite")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.